@@ -5,7 +5,7 @@
 
 /* nettle, low-level cryptographics library
  *
- * Copyright (C) 2001, 2002 Niels Mller
+ * Copyright (C) 2001, 2002 Niels Möller
  *  
  * The nettle library is free software; you can redistribute it and/or modify
  * it under the terms of the GNU Lesser General Public License as published by
@@ -19,8 +19,8 @@
  * 
  * You should have received a copy of the GNU Lesser General Public License
  * along with the nettle library; see the file COPYING.LIB.  If not, write to
- * the Free Software Foundation, Inc., 59 Temple Place - Suite 330, Boston,
- * MA 02111-1307, USA.
+ * the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston,
+ * MA 02111-1301, USA.
  */
 
 #ifndef NETTLE_PGP_H_INCLUDED
@@ -28,9 +28,12 @@
 
 #include <time.h>
 
-/* FIXME: User must include bignum.h before this file, in order to get
-   mpz_t defined. We don't do that here, in order to kludge through
-   compilation without public key support and without gmp.h. */
+#include "nettle-types.h"
+#include "bignum.h"
+
+#ifdef __cplusplus
+extern "C" {
+#endif
 
 /* Name mangling */
 #define pgp_put_uint32 nettle_pgp_put_uint32
@@ -230,4 +233,8 @@ enum pgp_subpacket_tag
     PGP_SUBPACKET_REASON_FOR_REVOCATION = 29,
   };
 
+#ifdef __cplusplus
+}
+#endif
+
 #endif /* NETTLE_PGP_H_INCLUDED */
